@@ -3,29 +3,24 @@ package Pod::ProjectDocs::DocManager;
 use strict;
 use warnings;
 
-our $VERSION = '0.48_004'; # TRIAL VERSION
+our $VERSION = '0.48_005';    # TRIAL VERSION
 
 use Moose;
+use Carp();
 use File::Find;
 use IO::File;
 use Pod::ProjectDocs::Doc;
 
-has 'config' => (
-    is => 'ro',
-);
+has 'config' => ( is => 'ro', );
 has 'desc' => (
-    is => 'rw',
+    is  => 'rw',
     isa => 'Str',
 );
-has 'suffix' => (
-    is => 'rw',
-);
-has 'parser' => (
-    is => 'ro',
-);
-has 'docs' => (
-    is => 'rw',
-    isa => 'ArrayRef',
+has 'suffix' => ( is => 'rw', );
+has 'parser' => ( is => 'ro', );
+has 'docs'   => (
+    is      => 'rw',
+    isa     => 'ArrayRef',
     default => sub { [] },
 );
 
@@ -39,11 +34,11 @@ sub _find_files {
     my $self = shift;
     foreach my $dir ( @{ $self->config->libroot } ) {
         unless ( -e $dir && -d _ ) {
-            $self->_croak(qq/$dir isn't detected or it's not a directory./);
+            Carp::croak(qq/$dir isn't detected or it's not a directory./);
         }
     }
     my $suffixs = $self->suffix;
-    $suffixs = [ $suffixs] if !ref $suffixs;
+    $suffixs = [$suffixs] if !ref $suffixs;
     foreach my $dir ( @{ $self->config->libroot } ) {
         foreach my $suffix (@$suffixs) {
             my $wanted = sub {
@@ -67,7 +62,8 @@ sub _find_files {
                 }
 
                 # check if there is actually any POD inside, skip otherwise
-                my $content = join('', IO::File->new( $File::Find::name, 'r' )->getlines());
+                my $content = join( '',
+                    IO::File->new( $File::Find::name, 'r' )->getlines() );
                 $matched = 1 if $content !~ m{^=(head1|head2|item|cut)}ismxg;
 
                 unless ($matched) {
@@ -87,16 +83,5 @@ sub _find_files {
     return;
 }
 
-sub get_docs {
-    my $self = shift;
-    return @{ $self->docs };
-}
-
-sub _croak {
-    my ( $self, $msg ) = @_;
-    require Carp;
-    Carp::croak($msg);
-}
-
 1;
 __END__
